import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Output, NgModule } from '@angular/core';
import * as i1 from 'angular-ng-autocomplete';
import { AutocompleteLibModule } from 'angular-ng-autocomplete';

class GoogleService {
    constructor() {
        this.arr = [];
        this.autoCompleteService = () => {
            return new Promise((resolve, reject) => {
                this.autocompleteService = new google.maps.places.AutocompleteService();
                if (this.autocompleteService !== undefined && this.autocompleteService !== null) {
                    resolve(this.autocompleteService);
                }
                else {
                    reject('AutoComplete Serice failed.');
                }
            });
        };
        this.placesService = () => {
            return new Promise((resolve, reject) => {
                this.placesSrv = new google.maps.places.PlacesService(document.createElement("div"));
                if (this.placesSrv !== undefined && this.placesSrv !== null) {
                    resolve(this.placesSrv);
                }
                else {
                    reject('Places Serice failed.');
                }
            });
        };
        this.setCurrentPosition = () => {
            return new Promise((resolve, reject) => {
                if ('geolocation' in navigator) {
                    navigator.geolocation.getCurrentPosition((position) => {
                        if (position !== undefined) {
                            resolve(position);
                        }
                        else {
                            reject('Failed to get current position.');
                        }
                    });
                }
            });
        };
        this.getQueryPredictions = (searchQuery) => {
            return new Promise((resolve, reject) => {
                const request = {
                    input: searchQuery,
                    componentRestrictions: { country: 'no' },
                    types: ['(address)']
                };
                this.autocompleteService.getQueryPredictions(request, (predictions, status) => {
                    if (status !== google.maps.places.PlacesServiceStatus.OK || !predictions) {
                        reject(status);
                    }
                    else {
                        if (predictions.length > 0) {
                            resolve(predictions);
                        }
                    }
                });
            });
        };
        this.getMyLocation = (latitude, longitude) => {
            return new Promise((resolve, reject) => {
                const myLocation = new google.maps.LatLng(latitude, longitude);
                const geocoder = new google.maps.Geocoder();
                geocoder.geocode({ 'latLng': myLocation }, (results, status) => {
                    if (status !== google.maps.places.PlacesServiceStatus.OK || !results) {
                        reject(status);
                    }
                    else {
                        if (results.length > 0) {
                            resolve(results);
                        }
                    }
                });
            });
        };
        if (!this.isGoogleLibExists()) {
            throw new Error('Google maps library can not be found');
        }
    }
    isGoogleLibExists() {
        return !(!google || !google.maps || !google.maps.places);
    }
}
GoogleService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.1", ngImport: i0, type: GoogleService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
GoogleService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.0.1", ngImport: i0, type: GoogleService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.1", ngImport: i0, type: GoogleService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class AngularGoogleAutocompleteComponent {
    constructor() {
        this.autocompleteResults = [];
        this.currentPoslatitude = 0;
        this.currentPoslongitude = 0;
        this.latitude = 0;
        this.longitude = 0;
        this.selectedPlace = new EventEmitter();
        this.keyword = 'description';
        this.data = [
            {
                id: 1,
                name: 'Usa'
            },
            {
                id: 2,
                name: 'England'
            }
        ];
        this.searchPlaces = (textQuery) => {
            this.googleService.getQueryPredictions(textQuery).then((predictions) => {
                if (predictions !== undefined && predictions !== null) {
                    this.autocompleteResults = predictions;
                }
            });
        };
        this.googleService = new GoogleService();
    }
    ngOnInit() {
        this.initialize();
    }
    initialize() {
        this.googleService.autoCompleteService().then((autocompService) => {
            this.autocompleteService = autocompService;
        });
        this.googleService.placesService().then((plcService) => {
            this.placesService = plcService;
        });
    }
    selectEvent(item) {
        // do something with selected item
        console.log(item);
        this.selectedPlace.emit(item);
    }
    onChangeSearch(textQuery) {
        if (textQuery !== undefined && textQuery !== null && textQuery !== "") {
            this.searchPlaces(textQuery);
        }
    }
    onFocused(e) {
        // do something when input is focused
        console.log(e);
    }
}
AngularGoogleAutocompleteComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.1", ngImport: i0, type: AngularGoogleAutocompleteComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
AngularGoogleAutocompleteComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.0.1", type: AngularGoogleAutocompleteComponent, selector: "angular-google-autocomplete", outputs: { selectedPlace: "selectedPlace" }, ngImport: i0, template: "<div class=\"ng-autocomplete\">\r\n      <ng-autocomplete\r\n        [data]=\"autocompleteResults\"\r\n        [searchKeyword]=\"keyword\"\r\n        (selected)='selectEvent($event)'\r\n        (inputChanged)='onChangeSearch($event)'\r\n        (inputFocused)='onFocused($event)'\r\n        [itemTemplate]=\"itemTemplate\"\r\n        [notFoundTemplate]=\"notFoundTemplate\"\r\n        placeholder=\"Adresse, Ole Brums vei 1\">\r\n      </ng-autocomplete>\r\n\r\n      <ng-template #itemTemplate let-item>\r\n        <ul class=\"list-group\">\r\n          <li class=\"list-group-item d-flex align-items-left\">\r\n            <div class=\"image-parent divIcon\">\r\n              <i class=\"fa fa-map-marker\"></i>\r\n            </div>\r\n            <div style=\"float: left;\">\r\n              <a [innerHTML]=\"item.description\"></a>\r\n            </div>\r\n          </li>\r\n        </ul>\r\n      </ng-template>\r\n\r\n      <ng-template #notFoundTemplate let-notFound>\r\n        <div [innerHTML]=\"notFound\"></div>\r\n      </ng-template>\r\n  </div>\r\n", styles: [".divIcon{margin-right:5px;width:10px;margin-top:13px;margin-left:10px}.ng-autocomplete{max-width:100%;width:100%}"], components: [{ type: i1.AutocompleteComponent, selector: "ng-autocomplete", inputs: ["data", "placeholder", "heading", "historyHeading", "historyListMaxNumber", "notFoundText", "minQueryLength", "focusFirst", "disabled", "searchKeyword", "initialValue", "historyIdentifier", "isLoading", "debounceTime", "customFilter", "itemTemplate", "notFoundTemplate"], outputs: ["selected", "inputChanged", "inputFocused", "inputCleared", "opened", "closed", "scrolledToEnd"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.1", ngImport: i0, type: AngularGoogleAutocompleteComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'angular-google-autocomplete',
                    templateUrl: `./angular-google-autocomplete.component.html`,
                    styleUrls: [`./angular-google-autocomplete.component.css`]
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { selectedPlace: [{
                type: Output
            }] } });

class AngularGoogleAutocompleteModule {
}
AngularGoogleAutocompleteModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.1", ngImport: i0, type: AngularGoogleAutocompleteModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AngularGoogleAutocompleteModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.0.1", ngImport: i0, type: AngularGoogleAutocompleteModule, declarations: [AngularGoogleAutocompleteComponent], imports: [AutocompleteLibModule], exports: [AngularGoogleAutocompleteComponent] });
AngularGoogleAutocompleteModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.0.1", ngImport: i0, type: AngularGoogleAutocompleteModule, imports: [[
            AutocompleteLibModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.1", ngImport: i0, type: AngularGoogleAutocompleteModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        AngularGoogleAutocompleteComponent
                    ],
                    imports: [
                        AutocompleteLibModule
                    ],
                    exports: [
                        AngularGoogleAutocompleteComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of angular-google-autocomplete
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AngularGoogleAutocompleteComponent, AngularGoogleAutocompleteModule, GoogleService };
//# sourceMappingURL=angular-google-autocomplete.js.map
